@@ -6,39 +6,18 @@
 
 #include "pgext.h"
 
-#define PGEXT_VERSION 5
-
-#define HSVL_START \
-    int shift = 0;\
-    int method = 0;\
-    Uint8 r,g,b,a;\
-    double hue,sat,val;\
-    double percent = 0;\
-
-#define HSVL_PRE \
-    if( method == 2 ){\
-        percent = ((double)(shift))/100.0;\
-    }\
-    for( y = 0; y < h; y ++ ){\
-        for( x = 0; x < w; x ++ ){\
-            pixel = pixels[(y*w)+x];\
-            SDL_GetRGBA( pixel, fmt, &r, &g, &b, &a );
-
-#define HSVL_END \
-            pixel = SDL_MapRGBA( fmt, r, g, b, a );\
-            pixels[ (y*w)+x ] = pixel;\
-        }\
-    }\
-    Py_INCREF(Py_None);\
-    return Py_None;
-
+#define PGEXT_VERSION 6
 
 /*
     Set all opaque (alpha>0) pixels to specified color (R,G,B).
 */
 static PyObject* setColor( PyObject* self, PyObject* args )
 {
-    SURFACE_INIT
+    PyObject* py_surface = NULL;
+    Uint32 *pixels;
+    int w,h,x,y = 0;
+    Uint32 pixel;
+    SDL_PixelFormat *format = NULL;
     PyObject *py_color = NULL;
     Uint8 color[4];
     Uint8 r,g,b,a;
@@ -46,18 +25,18 @@ static PyObject* setColor( PyObject* self, PyObject* args )
     PY_PARSEARGS_BEGIN
         "OO", &py_surface, &py_color
     PY_PARSEARGS_END
-    
+
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
+
     if(!RGBAFromColorObj (py_color, color))
         return Py_None;
     
-    SURFACE_PARAMS
-
     for( y = 0; y < h; y ++ ){
         for( x = 0; x < w; x ++ ){
             pixel = pixels[(y*w)+x];
-            SDL_GetRGBA( pixel, fmt, &r, &g, &b, &a );
+            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
             if(a==0) continue;
-            pixel = SDL_MapRGBA( fmt, color[0], color[1], color[2], a );
+            pixel = SDL_MapRGBA( format, color[0], color[1], color[2], a );
             pixels[ (y*w)+x ] = pixel;
         }
     }
@@ -75,7 +54,11 @@ static PyObject* setColor( PyObject* self, PyObject* args )
 */
 static PyObject* greyscale( PyObject* self, PyObject* args )
 {
-    SURFACE_INIT
+    PyObject* py_surface = NULL;
+    SDL_PixelFormat *format = NULL;
+    Uint32 *pixels;
+    int w,h,x,y = 0;
+    Uint32 pixel;
     Uint8 r,g,b,a;
     double hue,sat,val;
     int v;
@@ -85,24 +68,30 @@ static PyObject* greyscale( PyObject* self, PyObject* args )
         "O|i", &py_surface, &method
     PY_PARSEARGS_END
 
-    SURFACE_PARAMS
-
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
 
     for( y = 0; y < h; y ++ ){
         for( x = 0; x < w; x ++ ){
             pixel = pixels[(y*w)+x];
-            SDL_GetRGBA( pixel, fmt, &r, &g, &b, &a );
+            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
             if( method == 0 ){
                 /* average RGB */
                 v = (r+g+b)/3.0;
-                pixel = SDL_MapRGBA( fmt, v, v, v, a );
+                pixel = SDL_MapRGBA( format, v, v, v, a );
             }
             if( method == 1 ){
                 /* HSV stauration = 0 */
                 RGB2HSV( r, g, b, &hue, &sat, &val );
                 sat = 0;
                 HSV2RGB( hue, sat, val, &r, &g, &b );
-                pixel = SDL_MapRGBA( fmt, r, g, b, a );
+                pixel = SDL_MapRGBA( format, r, g, b, a );
+            }
+            if( method == 2 ){
+                /* HSL stauration = 0 */
+                RGB2HSL( r, g, b, &hue, &sat, &val );
+                sat = 0;
+                HSL2RGB( hue, sat, val, &r, &g, &b );
+                pixel = SDL_MapRGBA( format, r, g, b, a );
             }
             pixels[ (y*w)+x ] = pixel;
 
@@ -118,20 +107,24 @@ static PyObject* greyscale( PyObject* self, PyObject* args )
 */
 static PyObject* invert( PyObject* self, PyObject* args )
 {
-    SURFACE_INIT
+    PyObject* py_surface = NULL;
+    Uint32 *pixels;
+    int w,h,x,y = 0;
+    Uint32 pixel;
+    SDL_PixelFormat *format = NULL;
     Uint8 r,g,b,a;
 
     PY_PARSEARGS_BEGIN
         "O", &py_surface
     PY_PARSEARGS_END
 
-    SURFACE_PARAMS
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
 
     for( y = 0; y < h; y ++ ){
         for( x = 0; x < w; x ++ ){
             pixel = pixels[(y*w)+x];
-            SDL_GetRGBA( pixel, fmt, &r, &g, &b, &a );
-            pixel = SDL_MapRGBA( fmt, 255-r, 255-g, 255-b, a );
+            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
+            pixel = SDL_MapRGBA( format, 255-r, 255-g, 255-b, a );
             pixels[ (y*w)+x ] = pixel;
 
         }
@@ -147,18 +140,38 @@ static PyObject* invert( PyObject* self, PyObject* args )
 */
 static PyObject* hue( PyObject* self, PyObject* args )
 {
-    SURFACE_INIT
-    HSVL_START
+    PyObject* py_surface = NULL;
+    Uint32 *pixels;
+    int w,h,x,y = 0;
+    Uint32 pixel;
+    SDL_PixelFormat *format = NULL;
+    int shift = 0;
+    int method = 0;
+    Uint8 r,g,b,a;
+    double hue,sat,val;
+
     PY_PARSEARGS_BEGIN
         "Oi|i", &py_surface, &shift, &method
     PY_PARSEARGS_END
-    SURFACE_PARAMS
 
-    HSVL_PRE
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
+
+    for( y = 0; y < h; y ++ ){
+        for( x = 0; x < w; x ++ ){
+            pixel = pixels[(y*w)+x];
+            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
+
             RGB2HSV( r,g,b, &hue, &sat, &val );
-            hue += (double)(shift);
-            
-            /* clamp sat 0-100 */
+
+            if(method == 0){
+                hue += (double)(shift);
+            }
+
+            if(method == 1){
+                hue = (double)(shift);
+            }
+
+            /* clamp hue 0-100 */
             if( hue < 0 ){
                 hue = 360.0+hue;
             }
@@ -167,7 +180,13 @@ static PyObject* hue( PyObject* self, PyObject* args )
             }
             hue = clampValue( hue, 0.0, 360.0 );
             HSV2RGB( hue,sat,val, &r, &g, &b );
-    HSVL_END
+            pixel = SDL_MapRGBA( format, r, g, b, a );
+            pixels[ (y*w)+x ] = pixel;
+        }
+    }
+    Py_INCREF(Py_None);
+    return Py_None;
+
 }
 
 /*
@@ -179,14 +198,31 @@ static PyObject* hue( PyObject* self, PyObject* args )
 */
 static PyObject* saturation( PyObject* self, PyObject* args )
 {
-    SURFACE_INIT
-    HSVL_START
+    PyObject* py_surface = NULL;
+    Uint32 *pixels;
+    int w,h,x,y = 0;
+    Uint32 pixel;
+    SDL_PixelFormat *format = NULL;
+    int shift = 0;
+    int method = 0;
+    Uint8 r,g,b,a;
+    double hue,sat,val;
+    double percent = 0;
+
     PY_PARSEARGS_BEGIN
         "Oi|i", &py_surface, &shift, &method
     PY_PARSEARGS_END
-    SURFACE_PARAMS
+    
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
+
+    if( method == 2 ){
+        percent = ((double)(shift))/100.0;
+    }
+    for( y = 0; y < h; y ++ ){
+        for( x = 0; x < w; x ++ ){
+            pixel = pixels[(y*w)+x];
+            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
 
-    HSVL_PRE
             RGB2HSV( r,g,b, &hue, &sat, &val );
             if( method == 0 )
                 sat += (double)(shift);
@@ -200,7 +236,13 @@ static PyObject* saturation( PyObject* self, PyObject* args )
             /* clamp sat 0-100 */
             sat = clampValue( sat, 0.0, 100.0 );
             HSV2RGB( hue,sat,val, &r, &g, &b );
-    HSVL_END
+            pixel = SDL_MapRGBA( format, r, g, b, a );
+            pixels[ (y*w)+x ] = pixel;
+        }
+    }
+    Py_INCREF(Py_None);
+    return Py_None;
+
 }
 
 /*
@@ -212,14 +254,32 @@ static PyObject* saturation( PyObject* self, PyObject* args )
 */
 static PyObject* value( PyObject* self, PyObject* args )
 {
-    SURFACE_INIT
-    HSVL_START
+    PyObject* py_surface = NULL;
+    Uint32 *pixels;
+    int w,h,x,y = 0;
+    Uint32 pixel;
+    SDL_PixelFormat *format = NULL;
+
+    int shift = 0;
+    int method = 0;
+    Uint8 r,g,b,a;
+    double hue,sat,val;
+    double percent = 0;
+
     PY_PARSEARGS_BEGIN
         "Oi|i", &py_surface, &shift, &method
     PY_PARSEARGS_END
-    SURFACE_PARAMS
 
-    HSVL_PRE
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
+
+    if( method == 2 ){
+        percent = ((double)(shift))/100.0;
+    }
+    for( y = 0; y < h; y ++ ){
+        for( x = 0; x < w; x ++ ){
+            pixel = pixels[(y*w)+x];
+            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
+
             RGB2HSV( r,g,b, &hue, &sat, &val );
             if( method == 0 )
                 val += (double)(shift);
@@ -233,19 +293,42 @@ static PyObject* value( PyObject* self, PyObject* args )
             /* clamp sat 0-100 */
             val = clampValue( val, 0.0, 100.0 );
             HSV2RGB( hue,sat,val, &r, &g, &b );
-    HSVL_END
+            pixel = SDL_MapRGBA( format, r, g, b, a );
+            pixels[ (y*w)+x ] = pixel;
+        }
+    }
+    Py_INCREF(Py_None);
+    return Py_None;
+
 }
 
 static PyObject* lightness( PyObject* self, PyObject* args )
 {
-    SURFACE_INIT
-    HSVL_START
+    PyObject* py_surface = NULL;
+    Uint32 *pixels;
+    int w,h,x,y = 0;
+    Uint32 pixel;
+    SDL_PixelFormat *format = NULL;
+    int shift = 0;
+    int method = 0;
+    Uint8 r,g,b,a;
+    double hue,sat,val;
+    double percent = 0;
+
     PY_PARSEARGS_BEGIN
         "Oi|i", &py_surface, &shift, &method
     PY_PARSEARGS_END
-    SURFACE_PARAMS
+    
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
+
+    if( method == 2 ){
+        percent = ((double)(shift))/100.0;
+    }
+    for( y = 0; y < h; y ++ ){
+        for( x = 0; x < w; x ++ ){
+            pixel = pixels[(y*w)+x];
+            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
 
-    HSVL_PRE
             RGB2HSL( r,g,b, &hue, &sat, &val );
             if( method == 0 )
                 val += (double)(shift);
@@ -259,7 +342,13 @@ static PyObject* lightness( PyObject* self, PyObject* args )
             /* clamp sat 0-100 */
             val = clampValue( val, 0.0, 100.0 );
             HSL2RGB( hue,sat,val, &r, &g, &b );
-    HSVL_END
+            pixel = SDL_MapRGBA( format, r, g, b, a );
+            pixels[ (y*w)+x ] = pixel;
+        }
+    }
+    Py_INCREF(Py_None);
+    return Py_None;
+
 }
 
 /*
@@ -267,7 +356,11 @@ static PyObject* lightness( PyObject* self, PyObject* args )
 */
 static PyObject* colorize( PyObject* self, PyObject* args )
 {
-    SURFACE_INIT
+    PyObject* py_surface = NULL;
+    Uint32 *pixels;
+    int w,h,x,y = 0;
+    Uint32 pixel;
+    SDL_PixelFormat *format = NULL;
     int check_hue,new_hue;
     int s_shift = 0;
     int v_shift = 0;
@@ -281,12 +374,12 @@ static PyObject* colorize( PyObject* self, PyObject* args )
         &py_surface, &check_hue, &new_hue, &v_shift, &s_shift
     PY_PARSEARGS_END
     
-    SURFACE_PARAMS
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
 
     for( y = 0; y < h; y ++ ){
         for( x = 0; x < w; x ++ ){
             pixel = pixels[(y*w)+x];
-            SDL_GetRGBA( pixel, fmt, &r, &g, &b, &a );
+            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
             RGB2HSV( r,g,b, &hue, &sat, &val );
             if( (int)hue == check_hue ){
                 hue = new_hue;
@@ -304,7 +397,7 @@ static PyObject* colorize( PyObject* self, PyObject* args )
                 count++;
             }
             HSV2RGB( hue,sat,val, &r, &g, &b );
-            pixel = SDL_MapRGBA( fmt, r, g, b, a );
+            pixel = SDL_MapRGBA( format, r, g, b, a );
             pixels[ (y*w)+x ] = pixel;
 
         }
@@ -318,11 +411,14 @@ static PyObject* colorize( PyObject* self, PyObject* args )
 */
 static PyObject* alphaMask( PyObject* self, PyObject* args )
 {
-    SURFACE_INIT
+    PyObject* py_surface = NULL;
+    Uint32 *pixels;
+    int w,h,x,y,mw,mh = 0;
+    Uint32 pixel;
+    SDL_PixelFormat *format = NULL;
     PyObject* py_surface_mask = NULL;
-    PySurfaceObject *c_surface_mask;
     Uint32 *pixels_mask;
-    SDL_PixelFormat *fmt_mask = NULL;
+    SDL_PixelFormat *format_mask = NULL;
 
 
     Uint8 r,g,b,a;
@@ -334,12 +430,10 @@ static PyObject* alphaMask( PyObject* self, PyObject* args )
         &py_surface, &py_surface_mask
     PY_PARSEARGS_END
     
-    SURFACE_PARAMS
-    c_surface_mask = (PySurfaceObject*) py_surface_mask;
-    pixels_mask = (Uint32 *)c_surface_mask->surf->pixels;
-    fmt_mask = c_surface_mask->surf->format;
+    getSurfaceAttrs(py_surface_mask, &mw, &mh, &format_mask, &pixels_mask);
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
     
-    if( c_surface_mask->surf->w != w || c_surface_mask->surf->h != h ){
+    if( mw != w || mh != h ){
         return RAISE (PyExc_ValueError, "mask must be same size as surface");
     }
 
@@ -347,18 +441,18 @@ static PyObject* alphaMask( PyObject* self, PyObject* args )
         for( x = 0; x < w; x ++ ){
             /* get mask pixel*/
             pixel = pixels_mask[(y*w)+x];
-            SDL_GetRGBA( pixel, fmt_mask, &r, &g, &b, &a );
+            SDL_GetRGBA( pixel, format_mask, &r, &g, &b, &a );
             RGB2HSV( r,g,b, &hue, &sat, &val );
             if(val >= 99.9) continue;
             alpha = (float)(val/100.0);
             
             /* set pixel */
             pixel = pixels[(y*w)+x];
-            SDL_GetRGBA( pixel, fmt, &r, &g, &b, &a );
+            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
             
             a = (Uint8)(((float)a) * alpha );
             
-            pixel = SDL_MapRGBA( fmt, r, g, b, a );
+            pixel = SDL_MapRGBA( format, r, g, b, a );
             pixels[ (y*w)+x ] = pixel;
 
         }
